@@ -313,7 +313,7 @@ gpg_ctx_new (GMimeSession *session, const char *path)
 	gpg->mode = GPG_CTX_MODE_SIGN;
 	gpg->session = session;
 	g_object_ref (session);
-	gpg->userid_hint = g_hash_table_new (g_str_hash, g_str_equal);
+	gpg->userid_hint = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	gpg->complete = FALSE;
 	gpg->seen_eof1 = TRUE;
 	gpg->seen_eof2 = FALSE;
@@ -469,13 +469,6 @@ gpg_ctx_get_diagnostics (struct _GpgCtx *gpg)
 	return (const char *) gpg->diag->data;
 }
 
-static void
-userid_hint_free (gpointer key, gpointer value, gpointer user_data)
-{
-	g_free (key);
-	g_free (value);
-}
-
 static void
 gpg_ctx_free (struct _GpgCtx *gpg)
 {
@@ -485,7 +478,6 @@ gpg_ctx_free (struct _GpgCtx *gpg)
 	if (gpg->session)
 		g_object_unref (gpg->session);
 	
-	g_hash_table_foreach (gpg->userid_hint, userid_hint_free, NULL);
 	g_hash_table_destroy (gpg->userid_hint);
 	
 	g_free (gpg->path);
@@ -1959,7 +1951,7 @@ g_mime_gpg_context_new (GMimeSession *session, const char *path)
 	g_return_val_if_fail (GMIME_IS_SESSION (session), NULL);
 	g_return_val_if_fail (path != NULL, NULL);
 	
-	ctx = g_object_new (GMIME_TYPE_GPG_CONTEXT, NULL);
+	ctx = g_object_newv (GMIME_TYPE_GPG_CONTEXT, 0, NULL);
 	ctx->path = g_strdup (path);
 	
 	cipher = (GMimeCipherContext *) ctx;
