@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -49,10 +49,10 @@ static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
 static int stream_reset (GMimeStream *stream);
-static off_t stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-static off_t stream_tell (GMimeStream *stream);
+static gint64 stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
+static gint64 stream_tell (GMimeStream *stream);
 static ssize_t stream_length (GMimeStream *stream);
-static GMimeStream *stream_substream (GMimeStream *stream, off_t start, off_t end);
+static GMimeStream *stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
 
 static GMimeStreamClass *parent_class = NULL;
@@ -128,14 +128,14 @@ static ssize_t
 stream_read (GMimeStream *stream, char *buf, size_t len)
 {
 	GMimeStreamMem *mem = (GMimeStreamMem *) stream;
-	off_t bound_end;
+	gint64 bound_end;
 	ssize_t n;
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : (gint64) mem->buffer->len;
 	
-	n = MIN (bound_end - stream->position, (off_t) len);
+	n = MIN (bound_end - stream->position, (gint64) len);
 	if (n > 0) {
 		memcpy (buf, mem->buffer->data + stream->position, n);
 		stream->position += n;
@@ -151,7 +151,7 @@ static ssize_t
 stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	GMimeStreamMem *mem = (GMimeStreamMem *) stream;
-	off_t bound_end;
+	gint64 bound_end;
 	ssize_t n;
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
@@ -162,7 +162,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	} else
 		bound_end = stream->bound_end;
 	
-	n = MIN (bound_end - stream->position, (off_t) len);
+	n = MIN (bound_end - stream->position, (gint64) len);
 	if (n > 0) {
 		memcpy (mem->buffer->data + stream->position, buf, n);
 		stream->position += n;
@@ -199,11 +199,11 @@ static gboolean
 stream_eos (GMimeStream *stream)
 {
 	GMimeStreamMem *mem = (GMimeStreamMem *) stream;
-	off_t bound_end;
+	gint64 bound_end;
 	
 	g_return_val_if_fail (mem->buffer != NULL, TRUE);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : (gint64) mem->buffer->len;
 	
 	return stream->position >= bound_end;
 }
@@ -216,15 +216,15 @@ stream_reset (GMimeStream *stream)
 	return mem->buffer ? 0 : -1;
 }
 
-static off_t
-stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
+static gint64
+stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 {
 	GMimeStreamMem *mem = (GMimeStreamMem *) stream;
-	off_t bound_end, real = stream->position;
+	gint64 bound_end, real = stream->position;
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : (gint64) mem->buffer->len;
 	
 	switch (whence) {
 	case GMIME_STREAM_SEEK_SET:
@@ -248,7 +248,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 	return stream->position;
 }
 
-static off_t
+static gint64
 stream_tell (GMimeStream *stream)
 {
 	GMimeStreamMem *mem = (GMimeStreamMem *) stream;
@@ -262,27 +262,26 @@ static ssize_t
 stream_length (GMimeStream *stream)
 {
 	GMimeStreamMem *mem = GMIME_STREAM_MEM (stream);
-	off_t bound_end;
+	gint64 bound_end;
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : (gint64) mem->buffer->len;
 	
 	return bound_end - stream->bound_start;
 }
 
 static GMimeStream *
-stream_substream (GMimeStream *stream, off_t start, off_t end)
+stream_substream (GMimeStream *stream, gint64 start, gint64 end)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = FALSE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, start, end);
 	mem->buffer = GMIME_STREAM_MEM (stream)->buffer;
+	mem->owner = FALSE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), start, end);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
@@ -291,20 +290,19 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
  *
  * Creates a new GMimeStreamMem object.
  *
- * Returns a new memory stream.
+ * Returns: a new memory stream.
  **/
 GMimeStream *
 g_mime_stream_mem_new (void)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = g_byte_array_new ();
 	mem->owner = TRUE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
@@ -314,20 +312,19 @@ g_mime_stream_mem_new (void)
  *
  * Creates a new GMimeStreamMem with data @array.
  *
- * Returns a new memory stream using @array.
+ * Returns: a new memory stream using @array.
  **/
 GMimeStream *
 g_mime_stream_mem_new_with_byte_array (GByteArray *array)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = TRUE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = array;
+	mem->owner = TRUE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
@@ -339,22 +336,21 @@ g_mime_stream_mem_new_with_byte_array (GByteArray *array)
  * Creates a new GMimeStreamMem object and initializes the stream
  * contents with the first @len bytes of @buffer.
  *
- * Returns a new memory stream initialized with @buffer.
+ * Returns: a new memory stream initialized with @buffer.
  **/
 GMimeStream *
 g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = TRUE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = g_byte_array_new ();
+	mem->owner = TRUE;
 	
 	g_byte_array_append (mem->buffer, (unsigned char *) buffer, len);
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
@@ -364,7 +360,7 @@ g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
  *
  * Gets the byte array from the memory stream.
  *
- * Returns the byte array from the memory stream.
+ * Returns: the byte array from the memory stream.
  **/
 GByteArray *
 g_mime_stream_mem_get_byte_array (GMimeStreamMem *mem)
@@ -413,7 +409,7 @@ g_mime_stream_mem_set_byte_array (GMimeStreamMem *mem, GByteArray *array)
  *
  * Gets whether or not @mem owns the backend memory buffer.
  *
- * Returns %TRUE if @mem owns the backend memory buffer or %FALSE
+ * Returns: %TRUE if @mem owns the backend memory buffer or %FALSE
  * otherwise.
  **/
 gboolean
