@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -40,6 +40,7 @@
 #include <gmime/gmime-message-part.h>
 #include <gmime/gmime-message-partial.h>
 #include <gmime/internet-address.h>
+#include <gmime/gmime-encodings.h>
 #include <gmime/gmime-parser.h>
 #include <gmime/gmime-utils.h>
 #include <gmime/gmime-stream.h>
@@ -123,15 +124,12 @@ gboolean g_mime_check_version (guint major, guint minor, guint micro);
 
 
 /**
- * GMIME_INIT_FLAG_UTF8:
+ * GMIME_ENABLE_RFC2047_WORKAROUNDS:
  *
- * Initialization flag to enable UTF-8 interfaces throughout GMime.
- *
- * Note: this flag is really a no-op and remains only for backward
- * compatablity. Interfaces will be UTF-8 whether this flag is used or
- * not.
+ * Initialization flag to enable workarounds for badly formed rfc2047
+ * encoded-words.
  **/
-#define GMIME_INIT_FLAG_UTF8  (1 << 0)
+#define GMIME_ENABLE_RFC2047_WORKAROUNDS  (1 << 0)
 
 void g_mime_init (guint32 flags);
 void g_mime_shutdown (void);
