@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -30,8 +30,8 @@ G_BEGIN_DECLS
 typedef struct {
 	const char *pattern;
 	const char *prefix;
-	off_t um_so;
-	off_t um_eo;
+	size_t um_so;
+	size_t um_eo;
 } urlmatch_t;
 
 typedef gboolean (*UrlScanFunc) (const char *in, const char *pos, const char *inend, urlmatch_t *match);
